.. include:: ../README.rst

API documentation
=================

The following documentation is based on the source code of version |release| of
the `gentag` package:

.. contents::
   :local:

:mod:`gentag`
-------------

.. automodule:: gentag
   :members:

:mod:`gentag.exceptions`
------------------------

.. automodule:: gentag.exceptions
   :members:

:mod:`gentag.tests`
-------------------

.. automodule:: gentag.tests
   :members:
